// 基于Web环境下的webpack配置\
/* eslint @typescript-eslint/no-var-requires: "off" */
const path = require('path');
const { merge } = require('webpack-merge');
const HtmlWebpackPlugin = require('html-webpack-plugin');
const webpackBaseConfig = require('./webpack.base');
const ESLintPlugin = require('eslint-webpack-plugin');


const entry = {
  index: ['/src/main.tsx'],
};

const htmlWebpackPlugin = Object.keys(entry).map(
  name =>
    new HtmlWebpackPlugin({
      inject: 'body',
      scriptLoading: 'defer',
      template: path.join(__dirname, '../template/index.html'),
      minify: false,
      filename: `${name}.html`,
      chunks: [name],
    }),
);

const webpackDevConfig = {
  devtool: 'inline-source-map',
  entry: entry,
  output: {
    filename: '[name].index.js',
    publicPath: '/',
    library: 'elgo-rich',
    libraryTarget: 'umd',
    libraryExport: 'default',
  },
  mode: 'development',
  module: {},
  plugins: [
    ...htmlWebpackPlugin,
    new ESLintPlugin({
      extensions: ['js', 'ts', 'tsx'],
    }),
  ],
  devServer: {
    open: true,
    proxy: {
      '/elgo/api': {
        target: 'http://localhost:8070',
        ws: false, // 是否代理 websocket
        changeOrigin: true,
      },
      '/elgo/login': {
        target: 'http://localhost:8070',
        ws: false, // 是否代理 websocket
        changeOrigin: true,
      },
    },
  },
};

module.exports = merge(webpackBaseConfig, webpackDevConfig);
