// production webpack configuration
const path = require('path');
const { merge } = require('webpack-merge');
const HtmlWebpackPlugin = require('html-webpack-plugin');
const MiniCssExtractPlugin = require('mini-css-extract-plugin');
const CssMinimizerPlugin = require('css-minimizer-webpack-plugin');
const webpackBaseConfig = require('./webpack.base');
const CompressionPlugin = require('compression-webpack-plugin');

const hot = [];

const entry = {
  index: hot.concat(require.resolve('../src/index.ts')),
};

const htmlWebpackPlugin = Object.keys(entry).map(
  name =>
    new HtmlWebpackPlugin({
      inject: 'body',
      scriptLoading: 'defer',
      template: path.join(__dirname, '../template/index.html'),
      minify: false,
      filename: `${name}.html`,
      chunks: [name],
    }),
);

module.exports = merge(webpackBaseConfig, {
  mode: 'production',
  entry,
  devtool: false,
  output: {
    path: path.resolve(__dirname, '../dist'),
    filename: '[name].js',
    library: 'elgo-rich',
    libraryTarget: 'umd',
    // libraryExport: 'default',
  },

  module: {
    rules: [
      {
        test: /\.ts$/,
        exclude: [/node_modules/, /test/],
        use: [
          {
            loader: 'swc-loader',
          },
          {
            loader: 'ts-loader',
          },
        ],
      },
      {
        test: /.s?css$/,
        use: [MiniCssExtractPlugin.loader, 'css-loader', 'sass-loader'],
      },
    ],
  },
  plugins: [
    new MiniCssExtractPlugin(),
    new CompressionPlugin(),
    ...htmlWebpackPlugin,
  ],
  optimization: {
    minimize: true,
    minimizer: [new CssMinimizerPlugin()],
    splitChunks: {
      cacheGroups: {
        commons: {
          test: /(react|react-dom)/,
          name: 'vendors',
          chunks: 'all',
        },
      },
    },
  },
});
